@@ -39,7 +39,8 @@ from .const import (
     ATTR_POS,
     ATTR_AUTO_SET,
     BLOCK_INFO_VALUES,
-    SHELLY_TYPES
+    SHELLY_TYPES,
+    SRC_STATUS
 )
 
 class Block(Base):
@@ -53,7 +54,6 @@ class Block(Base):
         self.devices = []
         self.discovery_src = discovery_src
         self.protocols = []
-        self.cb_updated = []
         self.unavailable_after_sec = None
         #self.info_values = {}
         #self.info_values_updated = {}
@@ -74,8 +74,11 @@ class Block(Base):
     def update_coap(self, payload, ip_addr):
         self.ip_addr = ip_addr  # If changed ip
         self.last_updated = datetime.now()
-        self._update_info_values_coap(payload)
-        self.raise_updated()
+        self._update_info_values_coap(payload, BLOCK_INFO_VALUES)   
+
+        if self.payload:
+            self.set_info_value(INFO_VALUE_PAYLOAD, self.payload, None)
+     
         for dev in self.devices:
             dev.ip_addr = ip_addr
             dev._update_info_values_coap(payload)
@@ -90,10 +93,7 @@ class Block(Base):
                     dev.update_coap(payload)
                 self.parent.add_device(dev, self.discovery_src)
             self.reload = False
-
-    def raise_updated(self):
-        for callback in self.cb_updated:
-            callback(self)
+        self.raise_updated()
 
     def loop(self):
         if self._info_value_cfg:
@@ -108,15 +108,15 @@ class Block(Base):
                         if time:
                             diff = datetime.now() - time
                             if diff.total_seconds() > delay:
-                                self.info_values[iv] = new_val
+                                self.set_info_value(iv, new_value, None)
                                 self.raise_updated()
 
     def check_available(self):
         if self.available() != self._available:
             self._available = self.available()
-            self.raise_updated()
+            self.raise_updated(True)
             for dev in self.devices:
-                dev.raise_updated()
+                dev.raise_updated(True)
 
     def update_status_information(self):
         """Update the status information."""
@@ -143,20 +143,17 @@ class Block(Base):
             for name, cfg in self._info_value_cfg.items():
                 self._update_info_value(name, status, cfg)
 
-        if self.payload:
-            self.info_values[INFO_VALUE_PAYLOAD] = self.payload
-
+        cloud_status = 'disabled'
         if self.info_values.get(INFO_VALUE_CLOUD_ENABLED):
             if self.info_values.get(INFO_VALUE_CLOUD_CONNECTED):
-                self.info_values[INFO_VALUE_CLOUD_STATUS] = 'connected'
+                cloud_status = 'connected'
             else:
-                self.info_values[INFO_VALUE_CLOUD_STATUS] = 'disconnected'
-        else:
-            self.info_values[INFO_VALUE_CLOUD_STATUS] = 'disabled'
+                cloud_status = 'disconnected'
+        self.set_info_value(INFO_VALUE_CLOUD_STATUS, cloud_status, SRC_STATUS)
 
         #self.info_values[INFO_VALUE_HAS_FIRMWARE_UPDATE] = self.has_fw_update()
-        self.info_values[INFO_VALUE_LATEST_BETA_FW_VERSION] = \
-            self.latest_fw_version(True)
+        self.set_info_value(INFO_VALUE_LATEST_BETA_FW_VERSION,
+                            self.latest_fw_version(True), SRC_STATUS)
 
         self.raise_updated()
 
@@ -277,7 +274,7 @@ class Block(Base):
             self._add_device(RGBWW(self))
         #Shelly Dimmer
         elif self.type in ('SHDM-1', 'SHDM-2'):
-            self._info_value_cfg = {INFO_VALUE_DEVICE_TEMP : {ATTR_POS : 311}}
+            #self._info_value_cfg = {INFO_VALUE_DEVICE_TEMP : {ATTR_POS : 311}}
             self._add_device(Dimmer(self, [121, 1101], [111, 5101]))
             self._add_device(Switch(self, 1, position=[131, 2101]))
             self._add_device(Switch(self, 2, position=[131, 2101]))
@@ -285,8 +282,9 @@ class Block(Base):
         elif self.type == 'SHHT-1':
             self.sleep_device = True
             self.unavailable_after_sec = SENSOR_UNAVAILABLE_SEC
-            self._add_device(Sensor(self, 33, 'temperature', 'tmp/tC'))
-            self._add_device(Sensor(self, 44, 'humidity', 'hum/value'))
+            self.exclude_info_values.append(INFO_VALUE_DEVICE_TEMP)
+            self._add_device(Sensor(self, [33, 3101], 'temperature', 'tmp/tC'))
+            self._add_device(Sensor(self, [44, 3103], 'humidity', 'hum/value'))
         #Shellyy RGBW2
         elif self.type == 'SHRGBW2':
             if self.settings:
@@ -319,13 +317,14 @@ class Block(Base):
             self.sleep_device = True
             self.exclude_info_values.append(INFO_VALUE_DEVICE_TEMP)
             self.unavailable_after_sec = SENSOR_UNAVAILABLE_SEC
-            self._info_value_cfg = {INFO_VALUE_BATTERY : {ATTR_POS : 3111},
-                                    INFO_VALUE_TILT : {ATTR_POS : 3109},
+            self._info_value_cfg = {#INFO_VALUE_BATTERY : {ATTR_POS : 3111},
+                                    INFO_VALUE_TILT : {ATTR_POS : 3109, ATTR_PATH : 'accel/tilt'},
                                     INFO_VALUE_VIBRATION :
                                         {ATTR_POS : 6110,
+                                         ATTR_PATH : 'accel/vibration',
                                          ATTR_AUTO_SET: [0, 60]},
-                                    INFO_VALUE_TEMP: {ATTR_POS : 3101},
-                                    INFO_VALUE_ILLUMINANCE: {ATTR_POS : 3106}
+                                    INFO_VALUE_TEMP: {ATTR_POS : 3101}, #Todo
+                                    INFO_VALUE_ILLUMINANCE: {ATTR_POS : 3106, ATTR_PATH : 'lux/value'}
             }
             self._add_device(DoorWindow(self, 3108))
         elif self.type == 'SHBDUO-1':
@@ -337,6 +336,8 @@ class Block(Base):
             self._add_device(PowerMeter(self, 0, position=[141, 4101],
                                         tot_pos=[214, 4103]))
         elif self.type == 'SHBTN-1':
+            self.sleep_device = True
+            self.unavailable_after_sec = SENSOR_UNAVAILABLE_SEC
             self._add_device(Switch(self, 0, simulate_state=True,
                                     master_unit=True))
         elif self.type == 'SHIX3-1':
