@@ -12,13 +12,11 @@ class Device(Base):
         self.unit_id = block.id
         self.type = block.type
         self.ip_addr = block.ip_addr
-        self.cb_updated = []
         self.is_device = True
         self.is_sensor = False
         self.sub_name = None
         self.state_values = None
-        self.sensor_values = None
-        #self.info_values = None
+        #self.sensor_values = None
         self.state = None
         self.device_type = None
         self.device_sub_type = None #Used to make sensors unique
@@ -91,30 +89,27 @@ class Device(Base):
     def protocols(self):
         return self.block.protocols
 
-    def _update(self, new_state=None, new_state_values=None, new_values=None,
-                info_values=None):
+    def _update(self, new_state=None, new_state_values=None):
         LOGGER.debug(
-            "Update id:%s state:%s stateValue:%s values:%s info_values:%s",
-            self.id, new_state, new_state_values, new_values, info_values)
-        need_update = False
+            "Update id:%s state:%s stateValue:%s",
+            self.id, new_state, new_state_values)
         if new_state is not None:
             if self.state != new_state:
                 self.state = new_state
-                need_update = True
+                self.need_update = True
         if new_state_values is not None:
             if self.state_values != new_state_values:
                 self.state_values = new_state_values
-                need_update = True
-        if new_values is not None:
-            self.sensor_values = new_values
-            need_update = True
-        if info_values is not None:
-            self.info_values = info_values
-            need_update = True
+                self.need_update = True
+        #if new_values is not None:
+        #    self.sensor_values = new_values
+        #    self.need_update = True
+        #if info_values is not None:
+        #    self.info_values = info_values
+        #    self.need_update = True
         if self.lazy_load:
             self.block.parent.callback_add_device(self)
-        if need_update:
-            self.raise_updated()
+        self.raise_updated()
 
     def update_status_information(self, _status):
         """Update the status information."""
@@ -122,10 +117,6 @@ class Device(Base):
     def fw_version(self):
         return self.block.fw_version()
 
-    def raise_updated(self):
-        for callback in self.cb_updated:
-            callback(self)
-
     def close(self):
         self.cb_updated = []
 
